# API Docs - v1.0.16

## Sink

### email *<a target="_blank" href="https://siddhi.io/en/v4.x/docs/query-guide/#sink">(Sink)</a>*

<p style="word-wrap: break-word">The email sink uses 'smtp' server to publish events via emails. It can be published events in 'text', 'xml' or 'json' formats. The user can define email sink parameters in either 'deployment yaml' file or stream definition. So that email source checks whether parameters are given in stream definition or 'ymal' file respectively. If it is not given in both places, then default values are taken for the optional parameters. If user need to configure server system parameters which are not given as options in stream definition then it is needed to define them in 'yaml' file under email sink properties. (Refer link: https://javaee.github.io/javamail/SMTP-Transport to more information about smtp server parameters). Further, some email account required to enable 'access to less secure apps' option (for gmail account you can enable it via https://myaccount.google.com/lesssecureapps).</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
@sink(type="email", username="<STRING>", address="<STRING>", password="<STRING>", host="<STRING>", port="<INT>", ssl.enable="<BOOL>", auth="<BOOL>", content.type="<STRING>", subject="<STRING>", to="<STRING>", cc="<STRING>", bcc="<STRING>", attachments="<STRING>", @map(...)))
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">username</td>
        <td style="vertical-align: top; word-wrap: break-word">Username of the email account which is used to send emails (e.g: 'abc' is the username for abc@gmail.com).</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">address</td>
        <td style="vertical-align: top; word-wrap: break-word">Address of the email account which is used to send emails.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">password</td>
        <td style="vertical-align: top; word-wrap: break-word">Password of the email account.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">host</td>
        <td style="vertical-align: top; word-wrap: break-word">Host name of the smtp server (e.g. host name for a gmail account : 'smtp.gmail.com'). The default value 'smtp.gmail.com' is only valid if email account is a gmail account.</td>
        <td style="vertical-align: top">smtp.gmail.com</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">port</td>
        <td style="vertical-align: top; word-wrap: break-word">The port which is used to create the connection.</td>
        <td style="vertical-align: top">'465' the default value is only valid is ssl enable</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">ssl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">Whether the connection should be established through secure connection or not. The value can be either 'true' or 'false'. If it is 'true' then the connection is establish through 493 port which is secure connection.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">auth</td>
        <td style="vertical-align: top; word-wrap: break-word">Whether to use AUTH command or not, while authenticating. If true, then attempt to authenticate the user using the AUTH command.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">content.type</td>
        <td style="vertical-align: top; word-wrap: break-word">Content type can be either 'text/plain' or 'text/html'.</td>
        <td style="vertical-align: top">text/plain</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">subject</td>
        <td style="vertical-align: top; word-wrap: break-word">Subject of the mail which has to be send.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">to</td>
        <td style="vertical-align: top; word-wrap: break-word">Address of the 'to' recipients. If there are more than to recipients, then addresses can be given as a comma separated list.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">cc</td>
        <td style="vertical-align: top; word-wrap: break-word">Address of the 'cc' recipients. If there are more than cc recipients, then addresses can be given as a comma separated list.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">bcc</td>
        <td style="vertical-align: top; word-wrap: break-word">Address of the 'bcc' recipients. If there are more than bcc recipients, then addresses can be given as a comma separated list.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">attachments</td>
        <td style="vertical-align: top; word-wrap: break-word">File paths of the files that needs to be attached to the email.<br>These paths should be absolute paths.<br>They can be either a directories or files<br>. If it's a directory, all the files at its first level will be attached.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
</table>

<span id="system-parameters" class="md-typeset" style="display: block; font-weight: bold;">System Parameters</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Parameters</th>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, and a socket factory hasn't been specified, enables use of a MailSSLSocketFactory. If set to "*", all hosts are trusted. If set to a whitespace separated list of hosts, those hosts are trusted. Otherwise, trust depends on the certificate the server presents.</td>
        <td style="vertical-align: top">*</td>
        <td style="vertical-align: top">String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.connectiontimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket connection timeout value in milliseconds. </td>
        <td style="vertical-align: top">infinite timeout</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.timeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket I/O timeout value in milliseconds. </td>
        <td style="vertical-align: top">infinite timeout</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.from</td>
        <td style="vertical-align: top; word-wrap: break-word">Email address to use for SMTP MAIL command. This sets the envelope return address.</td>
        <td style="vertical-align: top">Defaults to msg.getFrom() or InternetAddress.getLocalAddress().</td>
        <td style="vertical-align: top">Valid email address</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.localport</td>
        <td style="vertical-align: top; word-wrap: break-word">Local port number to bind to when creating the SMTP socket.</td>
        <td style="vertical-align: top">Defaults to the port number picked by the Socket class.</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.ehlo</td>
        <td style="vertical-align: top; word-wrap: break-word">If false, do not attempt to sign on with the EHLO command.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.login.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTH LOGIN command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.plain.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTH PLAIN command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.digest-md5.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTH DIGEST-MD5 command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTH NTLM command</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.domain</td>
        <td style="vertical-align: top; word-wrap: break-word">The NTLM authentication domain.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid NTLM authentication domain name</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.flags</td>
        <td style="vertical-align: top; word-wrap: break-word">NTLM protocol-specific flags. See http://curl.haxx.se/rfc/ntlm.html#theNtlmFlags for details.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid NTLM protocol-specific flags.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.dsn.notify</td>
        <td style="vertical-align: top; word-wrap: break-word">The NOTIFY option to the RCPT command.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Either NEVER, or some combination of SUCCESS, FAILURE, and DELAY (separated by commas).</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.dsn.ret</td>
        <td style="vertical-align: top; word-wrap: break-word">The RET option to the MAIL command.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Either FULL or HDRS.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sendpartial</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, and a message has some valid and some invalid addresses, send the message anyway, reporting the partial failure with a SendFailedException. If set to false (the default), the message is not sent to any of the recipients if there is an invalid recipient address.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, attempt to use the javax.security.sasl package to choose an authentication mechanism for login.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.mechanisms</td>
        <td style="vertical-align: top; word-wrap: break-word">A space or comma separated list of SASL mechanism names to try to use.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.authorizationid</td>
        <td style="vertical-align: top; word-wrap: break-word">The authorization ID to use in the SASL authentication. If not set, the authentication ID (user name) is used.</td>
        <td style="vertical-align: top">username</td>
        <td style="vertical-align: top">Valid ID</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.realm</td>
        <td style="vertical-align: top; word-wrap: break-word">The realm to use with DIGEST-MD5 authentication.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.quitwait</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to false, the QUIT command is sent and the connection is immediately closed. If set to true (the default), causes the transport to wait for the response to the QUIT command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.reportsuccess</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, causes the transport to include an SMTPAddressSucceededException for each address that is successful.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to a class that implements the javax.net.SocketFactory interface, this class will be used to create SMTP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, specifies the name of a class that implements the javax.net.SocketFactory interface. This class will be used to create SMTP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory.fallback</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, failure to create a socket using the specified socket factory class will cause the socket to be created using the java.net.Socket class.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port to connect to when using the specified socket factory</td>
        <td style="vertical-align: top">25</td>
        <td style="vertical-align: top">Valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.ssl.protocols</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the SSL protocols that will be enabled for SSL connections.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">The property value is a whitespace separated list of tokens acceptable to the javax.net.ssl.SSLSocket.setEnabledProtocols method.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.starttls.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, enables the use of the STARTTLS command (if supported by the server) to switch the connection to a TLS-protected connection before issuing any login commands.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.starttls.required</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, requires the use of the STARTTLS command. If the server doesn't support the STARTTLS command, or the command fails, the connect method will fail.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socks.host</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the host name of a SOCKS5 proxy server that will be used for connections to the mail server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socks.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port number for the SOCKS5 proxy server. This should only need to be used if the proxy server is not using the standard port number of 1080.</td>
        <td style="vertical-align: top">1080</td>
        <td style="vertical-align: top">valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTH NTLM command</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.mailextension</td>
        <td style="vertical-align: top; word-wrap: break-word">Extension string to append to the MAIL command.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.userset</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, use the RSET command instead of the NOOP command in the isConnected method. In some cases sendmail will respond slowly after many NOOP commands; use of RSET avoids this sendmail issue.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@sink(type='email', @map(type ='json'), username='sender.account', address='sender.account@gmail.com',password='account.password',subject='Alerts from Wso2 Stream Processor',to='{{email}}',)define stream fooStream (email string, loginId int, name string);
```
<p style="word-wrap: break-word">Following example illustrates how to publish events using the email sinkusing mandatory parameters. As in the example, it publishes events come from the fooStream in json format via email sink to the given 'to' recipients. The email is sent by the sender.account@gmail.com via secure connection.</p>

<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
@sink(type='email', @map(type ='json'), subject='Alerts from Wso2 Stream Processor',to='{{email}}',)define stream fooStream (email string, loginId int, name string);
```
<p style="word-wrap: break-word">Following example illustrates how to configure the query parameters and system parameters in the deployment ymal file.<br>&nbsp;Corresponding parameters need to be configure under name:'email' and namespace:'sink' as follows<br>&nbsp;&nbsp;&nbsp;&nbsp;extensions:<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;-  extension:<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;name:'email'<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;namespace:'sink'<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;properties:<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;username: &lt;sender's email username&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;address: &lt;sender's email address&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;password: &lt;sender's email password&gt;<br><br>As in the example, it publishes events comefrom the fooStream in json format via email sink to the given 'to' recipients. The email is sent by the sender.account@gmail.com via secure connection.</p>

<span id="example-3" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 3</span>
```
@sink(type='email', @map(type ='json'), username='sender.account', address='sender.account@gmail.com',password='account.password',host='smtp.gmail.com',port='465',ssl.enable='true',auth='true',content.type='text/html',subject='Alerts from Wso2 Stream Processor-{{name}}',to='to1.account@gmail.com, to2.account@gmail.com',cc='cc1.account@gmail.com, cc2.account@gmail.com',bcc='bcc1.account@gmail.com)define stream fooStream (name string, age int, country string);
```
<p style="word-wrap: break-word">Following example illustrates how to publish events using the email sink. According to the example, it publishes events come from the fooStream in xml format via email sink as a text/html message to the given <code>to</code>,<code>cc</code> and <code>bcc</code> recipients using a secure connection. <code>name</code> in the <code>subject</code> attribute will be the value of the <code>name</code> parameter in the corresponding output event</p>

<span id="example-4" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 4</span>
```
@sink(type='email', @map(type ='json'), username='sender.account', address='sender.account@gmail.com',password='account.password',host='smtp.gmail.com',port='465',ssl.enable='true',auth='true',content.type='text/html',subject='Alerts from Wso2 Stream Processor-{{name}}',to='to1.account@gmail.com, to2.account@gmail.com',cc='cc1.account@gmail.com, cc2.account@gmail.com',bcc='bcc1.account@gmail.comattachments= '{{attachments}}')define stream fooStream (name string, age int, country string, attachments string);
```
<p style="word-wrap: break-word">Following example illustrates how to publish events using theemail sink. Here files are also attached to the email. According to the example, it publishes events come from the fooStream in xml format via email sink as a text/html message to the given <code>to</code>,<code>cc</code> and <code>bcc</code> recipients using a secure connection. <code>name</code> in the <code>subject</code> attribute will be the value of the <code>name</code> parameter in the corresponding output event.<br>&nbsp;Also to the same email message, the local file(s) related to the path received for the attribute attachments is/are attached.</p>

## Source

### email *<a target="_blank" href="https://siddhi.io/en/v4.x/docs/query-guide/#source">(Source)</a>*

<p style="word-wrap: break-word">Email source allows user to receive events via emails. Email source can be configured using 'imap' or 'pop3' server to receive events. This allows user to filter the messages which satisfy the given criteria under 'search term' option. The user can define email source parameters in either 'deployment yaml' file or stream definition. So that email source checks whether parameters are given in stream definition and 'ymal' file respectively. If it is not given in both places, then default values are taken if defaults values are available. If user need to configure server system parameters which are not given as options in stream definition then it is needed to define them in 'yaml' file under email source properties. (Refer link: https://javaee.github.io/javamail/IMAP-Store ,  https://javaee.github.io/javamail/POP3-Store to more information about imap and pop3 server system parameters).</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
@source(type="email", username="<STRING>", password="<STRING>", store="<STRING>", host="<STRING>", port="<INT>", folder="<STRING>", search.term="<STRING>", polling.interval="<LONG>", action.after.processed="<STRING>", folder.to.move="<STRING>", content.type="<STRING>", ssl.enable="<BOOL>", @map(...)))
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">username</td>
        <td style="vertical-align: top; word-wrap: break-word">user name of the email account. (e.g. wso2mail is the username of wso2mail@gmail.commail account.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">password</td>
        <td style="vertical-align: top; word-wrap: break-word">password of the email account</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">store</td>
        <td style="vertical-align: top; word-wrap: break-word">Store type that used to receive emails. it can be either imap or pop3.</td>
        <td style="vertical-align: top">imap</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">host</td>
        <td style="vertical-align: top; word-wrap: break-word">Host name of the server (e.g. host name for a gmail account with imap store : 'imap.gmail.com'). The default value imap.gmail.com' is only valid if email account is a gmail account with imap enable.</td>
        <td style="vertical-align: top">If store type is 'imap' then default value is 'imap.gmail.com' and if store type is 'pop3' thendefault value is 'pop3.gmail.com'.</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">port</td>
        <td style="vertical-align: top; word-wrap: break-word">The port which is used to create the connection.</td>
        <td style="vertical-align: top">'993' the default value is valid only if store is imap and ssl enable</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">folder</td>
        <td style="vertical-align: top; word-wrap: break-word">Name of the folder to fetch email.</td>
        <td style="vertical-align: top">INBOX</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">search.term</td>
        <td style="vertical-align: top; word-wrap: break-word">Option which includes conditions as a key value pairs to search emails. String search term should define ':' separated key and value with ',' separated key value pairs. Currently, this string search term only supported keys: subject, from, to, bcc, and cc. As an example: subject:DAS , from:carbon , bcc:wso2 string search term create a search term instance which filter emails contain 'DAS' in the subject, 'carbon' in the from address and 'wso2' in one of the bcc addresses. It does sub string matching which is case insensitive. But if '@' contains in the given value except for 'subject' key, then it check whether address is equal or not. As a example from: abc@ string search term check whether 'from' address is equal to 'abc' before '@' Symbol.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">polling.interval</td>
        <td style="vertical-align: top; word-wrap: break-word">Interval that email source should poll the account to check for new mails arrivals in seconds.</td>
        <td style="vertical-align: top">600</td>
        <td style="vertical-align: top">LONG</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">action.after.processed</td>
        <td style="vertical-align: top; word-wrap: break-word">Action that email source should carry out for the processed mail. FLAGGED : set the flag as falgged. SEEN : set the flag as read. ANSWERED : set the flag as answered. DELETE : delete tha mail after the polling cycle. MOVE : move the the mail to the folder given in folder.to.move. If folder is pop3, then only option available is 'DELETE</td>
        <td style="vertical-align: top">NONE</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">folder.to.move</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the folder, which mail has to move after processing.If the action after process is 'MOVE' then it is mandatory to define the folder to move.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">content.type</td>
        <td style="vertical-align: top; word-wrap: break-word">Content type of the email. It can be either 'text/plain' or 'text/html.'</td>
        <td style="vertical-align: top">text/plain</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">ssl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If it is 'true' then use a secure port to establish the connection. The possible values are 'true or false.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>

<span id="system-parameters" class="md-typeset" style="display: block; font-weight: bold;">System Parameters</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Parameters</th>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.partialfetch</td>
        <td style="vertical-align: top; word-wrap: break-word">Controls whether the IMAP partial-fetch capability should be used</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.fetchsize</td>
        <td style="vertical-align: top; word-wrap: break-word">Partial fetch size in bytes.</td>
        <td style="vertical-align: top">16K</td>
        <td style="vertical-align: top">value in bytes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.peek</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, use the IMAP PEEK option when fetching body parts, to avoid setting the SEEN flag on messages. Defaults to false. Can be overridden on a per-message basis by the setPeek method on IMAPMessage.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.connectiontimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket connection timeout value in milliseconds. This timeout is implemented by java.net.Socket.</td>
        <td style="vertical-align: top">infinity timeout</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.timeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket read timeout value in milliseconds. This timeout is implemented by java.net.Socket.</td>
        <td style="vertical-align: top">infinity timeout</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.writetimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket write timeout value in milliseconds. This timeout is implemented by using a java.util.concurrent.ScheduledExecutorService per connection that schedules a thread to close the socket if the timeout expires. Thus, the overhead of using this timeout is one thread per connection.</td>
        <td style="vertical-align: top">infinity timeout</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.statuscachetimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Timeout value in milliseconds for cache of STATUS command response.</td>
        <td style="vertical-align: top">1000ms</td>
        <td style="vertical-align: top">Time out in miliseconds</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.appendbuffersize</td>
        <td style="vertical-align: top; word-wrap: break-word">Maximum size of a message to buffer in memory when appending to an IMAP folder.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.connectionpoolsize</td>
        <td style="vertical-align: top; word-wrap: break-word">Maximum number of available connections in the connection pool.</td>
        <td style="vertical-align: top">1</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.connectionpooltimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Timeout value in milliseconds for connection pool connections. </td>
        <td style="vertical-align: top">45000ms</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.separatestoreconnection</td>
        <td style="vertical-align: top; word-wrap: break-word">Flag to indicate whether to use a dedicated store connection for store commands.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.login.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the non-standard AUTHENTICATE LOGIN command, instead using the plain LOGIN command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.plain.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTHENTICATE PLAIN command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.ntlm.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTHENTICATE NTLM command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.proxyauth.user</td>
        <td style="vertical-align: top; word-wrap: break-word">If the server supports the PROXYAUTH extension, this property specifies the name of the user to act as. Authenticate to the server using the administrator's credentials. After authentication, the IMAP provider will issue the PROXYAUTH command with the user name specified in this property.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.localaddress</td>
        <td style="vertical-align: top; word-wrap: break-word">Local address (host name) to bind to when creating the IMAP socket.</td>
        <td style="vertical-align: top">Defaults to the address picked by the Socket class.</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.localport</td>
        <td style="vertical-align: top; word-wrap: break-word">Local port number to bind to when creating the IMAP socket.</td>
        <td style="vertical-align: top">Defaults to the port number picked by the Socket class.</td>
        <td style="vertical-align: top">Valid String value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, attempt to use the javax.security.sasl package to choose an authentication mechanism for login.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.mechanisms</td>
        <td style="vertical-align: top; word-wrap: break-word">A space or comma separated list of SASL mechanism names to try to use.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.authorizationid</td>
        <td style="vertical-align: top; word-wrap: break-word">The authorization ID to use in the SASL authentication.</td>
        <td style="vertical-align: top">If not set, the authentication ID (user name) is used.</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.realm</td>
        <td style="vertical-align: top; word-wrap: break-word">The realm to use with SASL authentication mechanisms that require a realm, such as DIGEST-MD5.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.ntlm.domain</td>
        <td style="vertical-align: top; word-wrap: break-word">The NTLM authentication domain.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">The NTLM authentication domain.</td>
        <td style="vertical-align: top; word-wrap: break-word">NTLM protocol-specific flags.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to a class that implements the javax.net.SocketFactory interface, this class will be used to create IMAP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid SocketFactory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, specifies the name of a class that implements the javax.net.SocketFactory interface. This class will be used to create IMAP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory.fallback</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, failure to create a socket using the specified socket factory class will cause the socket to be created using the java.net.Socket class. </td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port to connect to when using the specified socket factory. Default port is used when not set.</td>
        <td style="vertical-align: top">143</td>
        <td style="vertical-align: top">Valid Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.checkserveridentity</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, check the server identity as specified by RFC 2595.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, and a socket factory hasn't been specified, enables use of a MailSSLSocketFactory.If set to '*', all hosts are trusted.If set to a whitespace separated list of hosts, those hosts are trusted.Otherwise, trust depends on the certificate the server presents.</td>
        <td style="vertical-align: top">*</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to a class that extends the javax.net.ssl.SSLSocketFactory class, this class will be used to create IMAP SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">SSL Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, specifies the name of a class that extends the javax.net.ssl.SSLSocketFactory class. This class will be used to create IMAP SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">the default port will be used-993</td>
        <td style="vertical-align: top">valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.protocols</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the SSL protocols that will be enabled for SSL connections. The property value is a whitespace separated list of tokens acceptable to the javax.net.ssl.SSLSocket.setEnabledProtocols method.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.starttls.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, enables the use of the STARTTLS command (if supported by the server) to switch the connection to a TLS-protected connection before issuing any login commands.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socks.host</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the host name of a SOCKS5 proxy server that will be used for connections to the mail server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socks.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port number for the SOCKS5 proxy server. This should only need to be used if the proxy server is not using the standard port number of 1080.</td>
        <td style="vertical-align: top">1080</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.minidletime</td>
        <td style="vertical-align: top; word-wrap: break-word">This property sets the delay in milliseconds.</td>
        <td style="vertical-align: top">10 milliseconds</td>
        <td style="vertical-align: top">time in seconds (Integer)</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.enableimapevents</td>
        <td style="vertical-align: top; word-wrap: break-word">Enable special IMAP-specific events to be delivered to the Store's ConnectionListener. If true, unsolicited responses received during the Store's idle method will be sent as ConnectionEvents with a type of IMAPStore.RESPONSE. The event's message will be the raw IMAP response string.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.folder.class</td>
        <td style="vertical-align: top; word-wrap: break-word">Class name of a subclass of com.sun.mail.imap.IMAPFolder. The subclass can be used to provide support for additional IMAP commands. The subclass must have public constructors of the form public MyIMAPFolder(String fullName, char separator, IMAPStore store, Boolean isNamespace) and public MyIMAPFolder(ListInfo li, IMAPStore store)</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.connectiontimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket connection timeout value in milliseconds.</td>
        <td style="vertical-align: top">Infinite timeout</td>
        <td style="vertical-align: top">Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.timeout</td>
        <td style="vertical-align: top; word-wrap: break-word">Socket I/O timeout value in milliseconds. </td>
        <td style="vertical-align: top">Infinite timeout</td>
        <td style="vertical-align: top">Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.message.class</td>
        <td style="vertical-align: top; word-wrap: break-word">Class name of a subclass of com.sun.mail.pop3.POP3Message</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.localaddress</td>
        <td style="vertical-align: top; word-wrap: break-word">Local address (host name) to bind to when creating the POP3 socket.</td>
        <td style="vertical-align: top">Defaults to the address picked by the Socket class.</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.localport</td>
        <td style="vertical-align: top; word-wrap: break-word">Local port number to bind to when creating the POP3 socket.</td>
        <td style="vertical-align: top">Defaults to the port number picked by the Socket class.</td>
        <td style="vertical-align: top">Valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.apop.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, use APOP instead of USER/PASS to login to the POP3 server, if the POP3 server supports APOP. APOP sends a digest of the password rather than the clear text password.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to a class that implements the javax.net.SocketFactory interface, this class will be used to create POP3 sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, specifies the name of a class that implements the javax.net. SocketFactory interface. This class will be used to create POP3 sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory.fallback</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, failure to create a socket using the specified socket factory class will cause the socket to be created using the java.net.Socket class.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">Default port</td>
        <td style="vertical-align: top">Valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.checkserveridentity</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, check the server identity as specified by RFC 2595. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, and a socket factory hasn't been specified, enables use of a MailSSLSocketFactory. If set to '*', all hosts are trusted.If set to a whitespace separated list of hosts, those hosts are trusted.Otherwise, trust depends on the certificate the server presents.</td>
        <td style="vertical-align: top">*</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to a class that extends the javax.net.ssl.SSLSocketFactory class, this class will be used to create POP3 SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">SSL Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.checkserveridentity</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, check the server identity as specified by RFC 2595. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word"> If set, and a socket factory hasn't been specified, enables use of a MailSSLSocketFactory.If set to '*', all hosts are trusted.If set to a whitespace separated list of hosts, those hosts are trusted. </td>
        <td style="vertical-align: top">trust depends on the certificate the server presents.</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to a class that extends the javax.net.ssl.SSLSocketFactory class, this class will be used to create POP3 SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">SSL Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If set, specifies the name of a class that extends the javax.net.ssl.SSLSocketFactory class. This class will be used to create POP3 SSL sockets. </td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory.p</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">995</td>
        <td style="vertical-align: top">Valid Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.protocols</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the SSL protocols that will be enabled for SSL connections. The property value is a whitespace separated list of tokens acceptable to the javax.net.ssl.SSLSocket.setEnabledProtocols method.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.starttls.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, enables the use of the STLS command (if supported by the server) to switch the connection to a TLS-protected connection before issuing any login commands</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.starttls.required</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, requires the use of the STLS command. If the server doesn't support the STLS command, or the command fails, the connect method will fail.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socks.host</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the host name of a SOCKS5 proxy server that will be used for connections to the mail server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socks.port</td>
        <td style="vertical-align: top; word-wrap: break-word">Specifies the port number for the SOCKS5 proxy server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.disabletop</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, the POP3 TOP command will not be used to fetch message headers. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.forgettopheaders</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, the headers that might have been retrieved using the POP3 TOP command will be forgotten and replaced by headers retrieved as part of the POP3 RETR command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.filecache.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If set to true, the POP3 provider will cache message data in a temporary file rather than in memory. Messages are only added to the cache when accessing the message content. Message headers are always cached in memory (on demand). The file cache is removed when the folder is closed or the JVM terminates.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.filecache.dir</td>
        <td style="vertical-align: top; word-wrap: break-word">If the file cache is enabled, this property can be used to override the default directory used by the JDK for temporary files.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.cachewriteto</td>
        <td style="vertical-align: top; word-wrap: break-word">Controls the behavior of the writeTo method on a POP3 message object. If set to true, and the message content hasn't yet been cached, and ignoreList is null, the message is cached before being written. Otherwise, the message is streamed directly to the output stream without being cached.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.keepmessagecontent</td>
        <td style="vertical-align: top; word-wrap: break-word">If this property is set to true, a hard reference to the cached content will be kept, preventing the memory from being reused until the folder is closed or the cached content is explicitly invalidated (using the invalidate method). </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@source(type='email', @map(type='xml'), username='receiver.account', password='account.password',)define stream inputStream (name string, age int, country string);
```
<p style="word-wrap: break-word">Following example illustrates how to receive events in <code>xml</code> format using email source. In this example only mandatory parameters are defined in the  in the stream definition. For other parameters default values are taken. since search term is not defined, it poll and take all new messages in the inbox folder</p>

<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
@source(type='email', @map(type='xml'), username='receiver.account', password='account.password',store = 'imap',host = 'imap.gmail.com',port = '993',searchTerm = 'subject:Stream Processor, from: from.account@ , cc: cc.account',polling.interval='500',action.after.processed='DELETE',content.type='text/html,)define stream inputStream (name string, age int, country string);
```
<p style="word-wrap: break-word">Following example illustrates how to receive events in <code>xml</code> format using email source. The email source polls the mail account in every 500 seconds to check whether new mails has been arrived and processes new mails only if if it satisfy the properties given under email search term (email messages which come from<code>from.account@.&lt;host name&gt;</code>, contains <code>cc.account</code> in cc receipts list, and <code>Stream Processor</code> words in the mail subject) In the example, action after processes is defined as the <code>DELETE</code>, so that after processing the event, corresponding mail is deleted from the mail folder.</p>

