# API Docs - v2.0.0

## Sink

### email *<a target="_blank" href="https://siddhi.io/en/v5.0/docs/query-guide/#sink">(Sink)</a>*

<p style="word-wrap: break-word">The email sink uses the 'smtp' server to publish events via emails. The events can be published in 'text', 'xml' or 'json' formats. The user can define email sink parameters in either the '&lt;SP_HOME&gt;/conf/&lt;PROFILE&gt;/deployment yaml' file or in the stream definition. The email sink first checks the stream definition for parameters, and if they are no configured there, it checks the 'deployment.yaml' file. If the parameters are not configured in either place, default values are considered for optional parameters. If you need to configure server system parameters that are not provided as options in the stream definition, then those parameters need to be defined them in the 'deployment.yaml' file under 'email sink properties'.<br><br>For more information about the SMTP server parameters, see  https://javaee.github.io/javamail/SMTP-Transport.<br><br>Further, some email accounts are required to enable the 'access to less secure apps' option. For gmail accounts, you can enable this option via https://myaccount.google.com/lesssecureapps.</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
@sink(type="email", username="<STRING>", address="<STRING>", password="<STRING>", host="<STRING>", port="<INT>", ssl.enable="<BOOL>", auth="<BOOL>", content.type="<STRING>", subject="<STRING>", to="<STRING>", cc="<STRING>", bcc="<STRING>", attachments="<STRING>", @map(...)))
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">username</td>
        <td style="vertical-align: top; word-wrap: break-word">The username of the email account that is used to send emails.<br>e.g., 'abc' is the username of the 'abc@gmail.com' account.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">address</td>
        <td style="vertical-align: top; word-wrap: break-word">The address of the email account that is used to send emails.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">password</td>
        <td style="vertical-align: top; word-wrap: break-word">The password of the email account.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">host</td>
        <td style="vertical-align: top; word-wrap: break-word">The host name of the SMTP server. e.g., 'smtp.gmail.com' is a host name for a gmail account. The default value 'smtp.gmail.com' is only valid if the email account is a gmail account.</td>
        <td style="vertical-align: top">smtp.gmail.com</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">port</td>
        <td style="vertical-align: top; word-wrap: break-word">The port that is used to create the connection.</td>
        <td style="vertical-align: top">'465' the default value is only valid is SSL is enabled.</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">ssl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter specifies whether the connection should be established via a secure connection or not. The value can be either 'true' or 'false'. If it is 'true', then the connection is establish via the  493 port which is a secure connection.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">auth</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter specifies whether to use the 'AUTH' command when authenticating or not. If the parameter is set to 'true', an attempt is made to authenticate the user using the 'AUTH' command.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">content.type</td>
        <td style="vertical-align: top; word-wrap: break-word">The content type can be either 'text/plain' or 'text/html'.</td>
        <td style="vertical-align: top">text/plain</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">subject</td>
        <td style="vertical-align: top; word-wrap: break-word">The subject of the mail to be send.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">to</td>
        <td style="vertical-align: top; word-wrap: break-word">The address of the 'to' recipient. If there are more than one 'to' recipients, then all the required addresses can be given as a comma-separated list.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">cc</td>
        <td style="vertical-align: top; word-wrap: break-word">The address of the 'cc' recipient. If there are more than one 'cc' recipients, then all the required addresses can be given as a comma-separated list.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">bcc</td>
        <td style="vertical-align: top; word-wrap: break-word">The address of the 'bcc' recipient. If there are more than one 'bcc' recipients, then all the required addresses can be given as a comma-separated list.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">attachments</td>
        <td style="vertical-align: top; word-wrap: break-word">File paths of the files that need to be attached to the email.<br>These paths should be absolute paths.<br>They can be either directories or files<br>. If the path is to a directory, all the files located at the first level (i.e., not within another sub directory) are attached.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
</table>

<span id="system-parameters" class="md-typeset" style="display: block; font-weight: bold;">System Parameters</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Parameters</th>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is se, and a socket factory has not been specified, it enables the use of a MailSSLSocketFactory. If this parameter is set to "*", all the hosts are trusted. If it is set to a whitespace-separated list of hosts, only those specified hosts are trusted. If not, the hosts trusted depends on the certificate presented by the server.</td>
        <td style="vertical-align: top">*</td>
        <td style="vertical-align: top">String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.connectiontimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket connection timeout value in milliseconds. </td>
        <td style="vertical-align: top">infinite timeout</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.timeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket I/O timeout value in milliseconds. </td>
        <td style="vertical-align: top">infinite timeout</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.from</td>
        <td style="vertical-align: top; word-wrap: break-word">The email address to use for the SMTP MAIL command. This sets the envelope return address.</td>
        <td style="vertical-align: top">Defaults to msg.getFrom() or InternetAddress.getLocalAddress().</td>
        <td style="vertical-align: top">Any valid email address</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.localport</td>
        <td style="vertical-align: top; word-wrap: break-word">The local port number to bind to when creating the SMTP socket.</td>
        <td style="vertical-align: top">Defaults to the port number picked by the Socket class.</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.ehlo</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'false', you must not attempt to sign in with the EHLO command.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.login.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this is set to 'true', it is not allowed to use the 'AUTH LOGIN' command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.plain.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is not allowed to use the 'AUTH PLAIN' command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.digest-md5.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is not allowed to use the 'AUTH DIGEST-MD5' command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is not allowed to use the 'AUTH NTLM' command</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.domain</td>
        <td style="vertical-align: top; word-wrap: break-word">The NTLM authentication domain.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">The valid NTLM authentication domain name.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.flags</td>
        <td style="vertical-align: top; word-wrap: break-word">NTLM protocol-specific flags. For more details, see http://curl.haxx.se/rfc/ntlm.html#theNtlmFlags.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid NTLM protocol-specific flags.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.dsn.notify</td>
        <td style="vertical-align: top; word-wrap: break-word">The NOTIFY option to the RCPT command.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Either 'NEVER', or a combination of 'SUCCESS', 'FAILURE', and 'DELAY' (separated by commas).</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.dsn.ret</td>
        <td style="vertical-align: top; word-wrap: break-word">The 'RET' option to the 'MAIL' command.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Either 'FULL' or 'HDRS'.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sendpartial</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true' and a message is addressed to both valid and invalid addresses, the message is sent with a log that reports the partial failure with a 'SendFailedException' error. If this parameter is set to 'false' (which is default), the message is not sent to any of the recipients when the recipient lists contain one or more invalid addresses.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the system attempts to use the 'javax.security.sasl' package to choose an authentication mechanism for the login.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.mechanisms</td>
        <td style="vertical-align: top; word-wrap: break-word">Enter a space or a comma-separated list of SASL mechanism names that the system shouldt try to use.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.authorizationid</td>
        <td style="vertical-align: top; word-wrap: break-word">The authorization ID to be used in the SASL authentication. If no value is specified, the authentication ID (i.e., username) is used.</td>
        <td style="vertical-align: top">username</td>
        <td style="vertical-align: top">Valid ID</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.sasl.realm</td>
        <td style="vertical-align: top; word-wrap: break-word">The realm to be used with the 'DIGEST-MD5' authentication.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.quitwait</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'false', the 'QUIT' command is issued and the connection is immediately closed. If this parameter is set to 'true' (which is default), the transport waits for the response to the QUIT command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.reportsuccess</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the transport to includes an 'SMTPAddressSucceededException' for each address to which the message is successfully delivered.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to a class that implements the 'javax.net.SocketFactory' interface, this class is used to create SMTP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set, it specifies the name of a class that implements the 'javax.net.SocketFactory interface'. This class is used to create SMTP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory.fallback</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the failure to create a socket using the specified socket factory class causes the socket to be created using the 'java.net.Socket' class.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">25</td>
        <td style="vertical-align: top">Valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.ssl.protocols</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the SSL protocols that need to be enabled for the SSL connections.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">This parameter specifies a whitespace separated list of tokens that are acceptable to the 'javax.net.ssl.SSLSocket.setEnabledProtocols' method.</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.starttls.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is possible to issue the 'STARTTLS' command (if supported by the server) to switch the connection to a TLS-protected connection before issuing any login commands.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.starttls.required</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is required to use the 'STARTTLS' command. If the server does not support the 'STARTTLS' command, or if the command fails, the connection method will fail.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socks.host</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the host name of a SOCKS5 proxy server to be used for the connections to the mail server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.socks.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the port number for the SOCKS5 proxy server. This needs to be used only if the proxy server is not using the standard port number 1080.</td>
        <td style="vertical-align: top">1080</td>
        <td style="vertical-align: top">valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.auth.ntlm.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the AUTH NTLM command cannot be issued.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.mailextension</td>
        <td style="vertical-align: top; word-wrap: break-word">The extension string to be appended to the MAIL command.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top"></td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.smtp.userset</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', you should use the 'RSET' command instead of the 'NOOP' command in the 'isConnected' method. In some scenarios, 'sendmail' responds slowly after many 'NOOP' commands. This is avoided by using 'RSET' instead.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@sink(type='email', @map(type ='json'), username='sender.account', address='sender.account@gmail.com',password='account.password',subject='Alerts from Wso2 Stream Processor',to='{{email}}',)define stream FooStream (email string, loginId int, name string);
```
<p style="word-wrap: break-word">This example illustrates how to publish events via an email sink based on the values provided for the mandatory parameters. As shown in the example, it publishes events from the 'FooStream' in 'json' format as emails to the specified 'to' recipients via the email sink. The email is sent from the 'sender.account@gmail.com' email address via a secure connection.</p>

<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
@sink(type='email', @map(type ='json'), subject='Alerts from Wso2 Stream Processor',to='{{email}}',)define stream FooStream (email string, loginId int, name string);
```
<p style="word-wrap: break-word">This example illustrates how to configure the query parameters and the system parameters in the 'deployment.yaml' file.<br>&nbsp;Corresponding parameters need to be configured under 'email', and namespace:'sink' as follows:<br>&nbsp;&nbsp;siddhi:     extensions:<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- extension:<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;name:'email'<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;namespace:'sink'<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;properties:<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;username: &lt;sender's email username&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;address: &lt;sender's email address&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;password: &lt;sender's email password&gt;<br><br>As shown in the example, events from the FooStream are published in 'json' format via the email sink as emails to the given 'to' recipients. The email is sent from the 'sender.account@gmail.com' address via a secure connection.</p>

<span id="example-3" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 3</span>
```
@sink(type='email', @map(type ='json'), username='sender.account', address='sender.account@gmail.com',password='account.password',host='smtp.gmail.com',port='465',ssl.enable='true',auth='true',content.type='text/html',subject='Alerts from Wso2 Stream Processor-{{name}}',to='to1.account@gmail.com, to2.account@gmail.com',cc='cc1.account@gmail.com, cc2.account@gmail.com',bcc='bcc1.account@gmail.com)define stream FooStream (name string, age int, country string);
```
<p style="word-wrap: break-word">This example illustrates how to publish events via the email sink. Events from the 'FooStream' stream  are published in 'xml' format via the email sink as a text/html message and sent to the specified 'to', 'cc', and 'bcc' recipients via a secure connection. The 'name' namespace in the 'subject' attribute is the value of the 'name' parameter in the corresponding output event.</p>

<span id="example-4" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 4</span>
```
@sink(type='email', @map(type ='json'), username='sender.account', address='sender.account@gmail.com',password='account.password',host='smtp.gmail.com',port='465',ssl.enable='true',auth='true',content.type='text/html',subject='Alerts from Wso2 Stream Processor-{{name}}',to='to1.account@gmail.com, to2.account@gmail.com',cc='cc1.account@gmail.com, cc2.account@gmail.com',bcc='bcc1.account@gmail.comattachments= '{{attachments}}')define stream FooStream (name string, age int, country string, attachments string);
```
<p style="word-wrap: break-word">This example illustrates how to publish events via the email sink. Here, the email also contains attachments.<br>&nbsp;Events from the FooStream are published in 'xml' format via the email sink as a 'text/html' message to the specified 'to','cc', and 'bcc' recipients via a secure connection. The 'name' namespace in the 'subject' attribute is the value for the 'name' parameter in the corresponding output event.<br>The attachments included in the email message are the local files available in the path specified as the value for the 'attachments' attribute.</p>

## Source

### email *<a target="_blank" href="https://siddhi.io/en/v5.0/docs/query-guide/#source">(Source)</a>*

<p style="word-wrap: break-word">The 'Email' source allows you to receive events via emails. An 'Email' source can be configured using the 'imap' or 'pop3' server to receive events. This allows you to filter the messages that satisfy the criteria specified under the 'search term' option. The email source parameters can be defined in either the '&lt;SP_HOME&gt;/conf/&lt;PROFILE&gt;/deployment yaml' file or the stream definition. If the parameter configurations are not available in either place, the default values are considered (i.e., if default values are available). If you need to configure server system parameters that are not provided as options in the stream definition, they need to be defined in the 'deployment yaml' file under 'email source properties'. For more information about 'imap' and 'pop3' server system parameters, see the following.<br>[JavaMail Reference Implementation - IMAP Store](https://javaee.github.io/javamail/IMAP-Store)<br>[JavaMail Reference Implementation - POP3 Store Store](https://javaee.github.io/javamail/POP3-Store)</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
@source(type="email", username="<STRING>", password="<STRING>", store="<STRING>", host="<STRING>", port="<INT>", folder="<STRING>", search.term="<STRING>", polling.interval="<LONG>", action.after.processed="<STRING>", folder.to.move="<STRING>", content.type="<STRING>", ssl.enable="<BOOL>", @map(...)))
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">username</td>
        <td style="vertical-align: top; word-wrap: break-word">The user name of the email account. e.g., 'wso2mail' is the username of the 'wso2mail@gmail.com' mail account.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">password</td>
        <td style="vertical-align: top; word-wrap: break-word">The password of the email account</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">store</td>
        <td style="vertical-align: top; word-wrap: break-word">The store type that used to receive emails. Possible values are 'imap' and 'pop3'.</td>
        <td style="vertical-align: top">imap</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">host</td>
        <td style="vertical-align: top; word-wrap: break-word">The host name of the server (e.g., 'imap.gmail.com' is the host name for a gmail account with an IMAP store.). The default value 'imap.gmail.com' is only valid if the email account is a gmail account with IMAP enabled.</td>
        <td style="vertical-align: top">If store type is 'imap', then the default value is 'imap.gmail.com'. If the store type is 'pop3', then thedefault value is 'pop3.gmail.com'.</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">port</td>
        <td style="vertical-align: top; word-wrap: break-word">The port that is used to create the connection.</td>
        <td style="vertical-align: top">'993', the default value is valid only if the store is 'imap' and ssl-enabled.</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">folder</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the folder to which the emails should be fetched.</td>
        <td style="vertical-align: top">INBOX</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">search.term</td>
        <td style="vertical-align: top; word-wrap: break-word">The option that includes conditions such as key-value pairs to search for emails. In a string search term, the key and the value should be separated by a semicolon (';'). Each key-value pair must be within inverted commas (' '). The string search term can define multiple comma-separated key-value pairs. This string search term currently supports only the 'subject', 'from', 'to', 'bcc', and 'cc' keys. e.g., if you enter 'subject:DAS, from:carbon, bcc:wso2', the search term creates a search term instance that filters emails that contain 'DAS' in the subject, 'carbon' in the 'from' address, and 'wso2' in one of the 'bcc' addresses. The string search term carries out sub string matching that is case-sensitive. If '@' in included in the value for any key other than the 'subject' key, it checks for an address that is equal to the value given. e.g., If you search for 'abc@', the string search terms looks for an address that contains 'abc' before the '@' symbol.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">polling.interval</td>
        <td style="vertical-align: top; word-wrap: break-word">This defines the time interval in seconds at which th email source should poll the account to check for new mail arrivals.in seconds.</td>
        <td style="vertical-align: top">600</td>
        <td style="vertical-align: top">LONG</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">action.after.processed</td>
        <td style="vertical-align: top; word-wrap: break-word">The action to be performed by the email source for the processed mail. Possible values are as follows:<br>'FLAGGED': Sets the flag as 'flagged'.<br>'SEEN': Sets the flag as 'read'.<br>'ANSWERED': Sets the flag as 'answered'.<br>'DELETE': Deletes tha mail after the polling cycle.<br>'MOVE': Moves the mail to the folder specified in the 'folder.to.move' parameter.<br>&nbsp;If the folder specified is 'pop3', then the only option available is 'DELETE'.</td>
        <td style="vertical-align: top">NONE</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">folder.to.move</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the folder to which the mail must be moved once it is processed. If the action after processing is 'MOVE', it is required to specify a value for this parameter.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">content.type</td>
        <td style="vertical-align: top; word-wrap: break-word">The content type of the email. It can be either 'text/plain' or 'text/html.'</td>
        <td style="vertical-align: top">text/plain</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">ssl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this is set to 'true', a secure port is used to establish the connection. The possible values are 'true' and 'false'.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>

<span id="system-parameters" class="md-typeset" style="display: block; font-weight: bold;">System Parameters</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Parameters</th>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.partialfetch</td>
        <td style="vertical-align: top; word-wrap: break-word">This determines whether the IMAP partial-fetch capability should be used.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.fetchsize</td>
        <td style="vertical-align: top; word-wrap: break-word">The partial fetch size in bytes.</td>
        <td style="vertical-align: top">16K</td>
        <td style="vertical-align: top">value in bytes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.peek</td>
        <td style="vertical-align: top; word-wrap: break-word">If this is set to 'true', the IMAP PEEK option should be used when fetching body parts to avoid setting the 'SEEN' flag on messages. The default value is 'false'. This can be overridden on a per-message basis by the 'setPeek method' in 'IMAPMessage'.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.connectiontimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket connection timeout value in milliseconds. This timeout is implemented by 'java.net.Socket'.</td>
        <td style="vertical-align: top">infinity timeout</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.timeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket read timeout value in milliseconds. This timeout is implemented by 'java.net.Socket'.</td>
        <td style="vertical-align: top">infinity timeout</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.writetimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket write timeout value in milliseconds. This timeout is implemented by using a 'java.util.concurrent.ScheduledExecutorService' per connection that schedules a thread to close the socket if the timeout period elapses. Therefore, the overhead of using this timeout is one thread per connection.</td>
        <td style="vertical-align: top">infinity timeout</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.statuscachetimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The timeout value in milliseconds for the cache of 'STATUS' command response.</td>
        <td style="vertical-align: top">1000ms</td>
        <td style="vertical-align: top">Time out in miliseconds</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.appendbuffersize</td>
        <td style="vertical-align: top; word-wrap: break-word">The maximum size of a message to buffer in memory when appending to an IMAP folder.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.connectionpoolsize</td>
        <td style="vertical-align: top; word-wrap: break-word">The maximum number of available connections in the connection pool.</td>
        <td style="vertical-align: top">1</td>
        <td style="vertical-align: top">Any Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.connectionpooltimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The timeout value in milliseconds for connection pool connections. </td>
        <td style="vertical-align: top">45000ms</td>
        <td style="vertical-align: top">Any Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.separatestoreconnection</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it indicates that a dedicated store connection needs to be used for store commands.</td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.login.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this is set to 'true', it is not possible to use the non-standard 'AUTHENTICATE LOGIN' command instead of the plain 'LOGIN' command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.plain.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this is set to 'true', the 'AUTHENTICATE PLAIN' command cannot be used.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.ntlm.disable</td>
        <td style="vertical-align: top; word-wrap: break-word">If true, prevents use of the AUTHENTICATE NTLM command.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.proxyauth.user</td>
        <td style="vertical-align: top; word-wrap: break-word">If the server supports the PROXYAUTH extension, this property specifies the name of the user to act as. Authentication to log in to the server is carried out using the administrator's credentials. After authentication, the IMAP provider issues the 'PROXYAUTH' command with the user name specified in this property.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.localaddress</td>
        <td style="vertical-align: top; word-wrap: break-word">The local address (host name) to bind to when creating the IMAP socket.</td>
        <td style="vertical-align: top">Defaults to the address picked by the Socket class.</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.localport</td>
        <td style="vertical-align: top; word-wrap: break-word">The local port number to bind to when creating the IMAP socket.</td>
        <td style="vertical-align: top">Defaults to the port number picked by the Socket class.</td>
        <td style="vertical-align: top">Valid String value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the system attempts to use the 'javax.security.sasl' package to choose an authentication mechanism for the login.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.mechanisms</td>
        <td style="vertical-align: top; word-wrap: break-word">A list of SASL mechanism names that the system should to try to use. The names can be separated by spaces or commas.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.authorizationid</td>
        <td style="vertical-align: top; word-wrap: break-word">The authorization ID to use in the SASL authentication.</td>
        <td style="vertical-align: top">If this parameter is not set, the authentication ID (username) is used.</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.sasl.realm</td>
        <td style="vertical-align: top; word-wrap: break-word">The realm to use with SASL authentication mechanisms that require a realm, such as 'DIGEST-MD5'.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.auth.ntlm.domain</td>
        <td style="vertical-align: top; word-wrap: break-word">The NTLM authentication domain.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">The NTLM authentication domain.</td>
        <td style="vertical-align: top; word-wrap: break-word">NTLM protocol-specific flags.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to a class that implements the 'javax.net.SocketFactory' interface, this class is used to create IMAP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid SocketFactory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set, it specifies the name of a class that implements the 'javax.net.SocketFactory' interface. This class is used to create IMAP sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory.fallback</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', failure to create a socket using the specified socket factory class results in the socket being created using the 'java.net.Socket' class. </td>
        <td style="vertical-align: top">true</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the port to connect to when using the specified socket factory. If this parameter is not set, the default port is used.</td>
        <td style="vertical-align: top">143</td>
        <td style="vertical-align: top">Valid Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.checkserveridentity</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the system checks the server identity as specified by RFC 2595.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set and a socket factory has not been specified, it enables the use of a 'MailSSLSocketFactory'.<br>If this parameter is set to '*', all the hosts are trusted.<br>If this parameter specifies list of hosts separated by white spaces, only those hosts are trusted.<br>If the parameter is not set to any of the values mentioned above, trust depends on the certificate presented by the server.</td>
        <td style="vertical-align: top">*</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to a class that extends the 'javax.net.ssl.SSLSocketFactory' class this class is used to create IMAP SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">SSL Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set, it specifies the name of a class that extends the 'javax.net.ssl.SSLSocketFactory' class. This class is used to create IMAP SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">the default port 993 is used.</td>
        <td style="vertical-align: top">valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.ssl.protocols</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the SSL protocols that are enabled for SSL connections. The property value is a whitespace-separated list of tokens acceptable to the 'javax.net.ssl.SSLSocket.setEnabledProtocols' method.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid string</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.starttls.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is possible to use the 'STARTTLS' command (if supported by the server) to switch the connection to a TLS-protected connection before issuing any login commands.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socks.host</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the host name of a 'SOCKS5' proxy server that is used to connect to the mail server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.socks.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the port number for the 'SOCKS5' proxy server. This is needed if the proxy server is not using the standard port number 1080.</td>
        <td style="vertical-align: top">1080</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.minidletime</td>
        <td style="vertical-align: top; word-wrap: break-word">This property sets the delay in milliseconds.</td>
        <td style="vertical-align: top">10 milliseconds</td>
        <td style="vertical-align: top">time in seconds (Integer)</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.enableimapevents</td>
        <td style="vertical-align: top; word-wrap: break-word">If this property is set to 'true', it enables special IMAP-specific events to be delivered to the 'ConnectionListener' of the store. The unsolicited responses received during the idle method of the store are sent as connection events with 'IMAPStore.RESPONSE' as the type. The event's message is the raw IMAP response string.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.imap.folder.class</td>
        <td style="vertical-align: top; word-wrap: break-word">The class name of a subclass of 'com.sun.mail.imap.IMAPFolder'. The subclass can be used to provide support for additional IMAP commands. The subclass must have public constructors of the form 'public MyIMAPFolder'(String fullName, char separator, IMAPStore store, Boolean isNamespace) and public 'MyIMAPFolder'(ListInfo li, IMAPStore store)</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.connectiontimeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket connection timeout value in milliseconds.</td>
        <td style="vertical-align: top">Infinite timeout</td>
        <td style="vertical-align: top">Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.timeout</td>
        <td style="vertical-align: top; word-wrap: break-word">The socket I/O timeout value in milliseconds. </td>
        <td style="vertical-align: top">Infinite timeout</td>
        <td style="vertical-align: top">Integer value</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.message.class</td>
        <td style="vertical-align: top; word-wrap: break-word">The class name of a subclass of 'com.sun.mail.pop3.POP3Message'.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.localaddress</td>
        <td style="vertical-align: top; word-wrap: break-word">The local address (host name) to bind to when creating the POP3 socket.</td>
        <td style="vertical-align: top">Defaults to the address picked by the Socket class.</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.localport</td>
        <td style="vertical-align: top; word-wrap: break-word">The local port number to bind to when creating the POP3 socket.</td>
        <td style="vertical-align: top">Defaults to the port number picked by the Socket class.</td>
        <td style="vertical-align: top">Valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.apop.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', use 'APOP' instead of 'USER/PASS' to log in to the 'POP3' server (if the 'POP3' server supports 'APOP'). APOP sends a digest of the password instead of clearing the text password.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to a class that implements the 'javax.net.SocketFactory' interface, this class is used to create 'POP3' sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set, it specifies the name of a class that implements the 'javax.net.SocketFactory' interface. This class is used to create 'POP3' sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory.fallback</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', failure to create a socket using the specified socket factory class results in the socket being created using the 'java.net.Socket' class.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socketFactory.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This specifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">Default port</td>
        <td style="vertical-align: top">Valid port number</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.checkserveridentity</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', check the server identity as specified by RFC 2595. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set and a socket factory has not been specified, it is possible to use a 'MailSSLSocketFactory'. <br>If this parameter is set to '*', all the hosts are trusted.<br>If the parameter is set to a whitespace-separated list of hosts, only those hosts are trusted.<br>If the parameter is not set to any of the values mentioned above, trust depends on the certificate presented by the server.</td>
        <td style="vertical-align: top">*</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to a class that extends the 'javax.net.ssl.SSLSocketFactory' class, this class is used to create 'POP3' SSL sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">SSL Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.checkserveridentity</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the system checks the server identity as specified by 'RFC 2595'. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.trust</td>
        <td style="vertical-align: top; word-wrap: break-word"> If this parameter is set and a socket factory has not been specified, it is possible to use a 'MailSSLSocketFactory'.<br>If this parameter is set to '*', all the hosts are trusted.<br>If the parameter is set to a whitespace-separated list of hosts, only those hosts are trusted.</td>
        <td style="vertical-align: top">Trust depends on the certificate presented by the server.</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to a class that extends the 'javax.net.ssl.SSLSocketFactory' class, this class is used to create 'POP3 SSL' sockets.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">SSL Socket Factory</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory.class</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set, it specifies the name of a class that extends the 'javax.net.ssl.SSLSocketFactory' class. This class is used to create 'POP3 SSL' sockets. </td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.socketFactory.p</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter pecifies the port to connect to when using the specified socket factory.</td>
        <td style="vertical-align: top">995</td>
        <td style="vertical-align: top">Valid Integer</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.ssl.protocols</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter specifies the SSL protocols that are enabled for SSL connections. The property value is a whitespace-separated list of tokens acceptable to the 'javax.net.ssl.SSLSocket.setEnabledProtocols' method.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.starttls.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is possible to use the 'STLS' command (if supported by the server) to switch the connection to a TLS-protected connection before issuing any login commands.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.starttls.required</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', it is required to use the 'STLS' command. The connect method fails if the server does not support the 'STLS' command or if the command fails.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socks.host</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter specifies the host name of a 'SOCKS5' proxy server that can be used to connect to the mail server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.socks.port</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter specifies the port number for the 'SOCKS5' proxy server.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.disabletop</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the 'POP3 TOP' command is not used to fetch message headers. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.forgettopheaders</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the headers that might have been retrieved using the 'POP3 TOP' command is forgotten and replaced by the headers retrieved when the 'POP3 RETR' command is executed.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.filecache.enable</td>
        <td style="vertical-align: top; word-wrap: break-word">If this parameter is set to 'true', the 'POP3' provider caches message data in a temporary file instead of caching them in memory. Messages are only added to the cache when accessing the message content. Message headers are always cached in memory (on demand). The file cache is removed when the folder is closed or the JVM terminates.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.filecache.dir</td>
        <td style="vertical-align: top; word-wrap: break-word">If the file cache is enabled, this property is used to override the default directory used by the JDK for temporary files.</td>
        <td style="vertical-align: top">None</td>
        <td style="vertical-align: top">Valid String</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.cachewriteto</td>
        <td style="vertical-align: top; word-wrap: break-word">This parameter controls the behavior of the 'writeTo' method on a 'POP3' message object. If the parameter is set to 'true', the message content has not been cached yet, and the 'ignoreList' is null, the message is cached before being written. If not, the message is streamed directly to the output stream without being cached.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
    <tr>
        <td style="vertical-align: top">mail.pop3.keepmessagecontent</td>
        <td style="vertical-align: top; word-wrap: break-word">If this property is set to 'true', a hard reference to the cached content is retained, preventing the memory from being reused until the folder is closed, or until the cached content is explicitly invalidated (using the 'invalidate' method). </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">true or false</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@source(type='email', @map(type='xml'), username='receiver.account', password='account.password',)define stream inputStream (name string, age int, country string);
```
<p style="word-wrap: break-word">This example illustrates how to receive events in 'xml' format via the email source. In this example, only the required parameters are defined in the stream definition. The default values are taken for the other parameters. The search term is not defined, and therefore, all the new messages in the inbox folder are polled and taken.</p>

<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
@source(type='email', @map(type='xml'), username='receiver.account', password='account.password',store = 'imap',host = 'imap.gmail.com',port = '993',searchTerm = 'subject:Stream Processor, from: from.account@ , cc: cc.account',polling.interval='500',action.after.processed='DELETE',content.type='text/html,)define stream inputStream (name string, age int, country string);
```
<p style="word-wrap: break-word">This example illustrates how to receive events in 'xml' format via the email source. The email source polls the mail account every 500 seconds to check whether any new mails have arrived. It processes new mails only if they satisfy the conditions specified for the email search term (the value for 'from' of the email message should be 'from.account@.&lt;host name&gt;', and the message should contain 'cc.account' in the cc receipient list and the word 'Stream Processor' in the mail subject). in this example, the action after processing is 'DELETE'. Therefore,after processing the event, corresponding mail is deleted from the mail folder.</p>

